// ====================================================
//
// Copyright (c) 2002 Sean Wilson. All Rights Reserved.
//
// ====================================================

#include "color.h"

namespace seanw
{
namespace graphics
{

const int Color::MAX_INTENSITY = 255;

const Color Color::BLACK(                       0,                        0,                        0);
const Color Color::WHITE(    Color::MAX_INTENSITY,     Color::MAX_INTENSITY,     Color::MAX_INTENSITY);
const Color Color::RED  (    Color::MAX_INTENSITY,                        0,                        0);
const Color Color::GREEN(                       0,     Color::MAX_INTENSITY,                        0);
const Color Color::BLUE (                       0,                        0,     Color::MAX_INTENSITY);
const Color Color::GREY (Color::MAX_INTENSITY / 2, Color::MAX_INTENSITY / 2, Color::MAX_INTENSITY / 2);

Color::Color(int initRed, int initGreen, int initBlue) :
	red  (initRed),
	green(initGreen),
	blue (initBlue)
{
	if (red < 0 || red > MAX_INTENSITY)
	{
		throw std::out_of_range(misc::getErrorString(__FILE__, __LINE__, "Red component is not within correct range.").c_str());
	}

	if (green < 0 || green > MAX_INTENSITY)
	{
		throw std::out_of_range(misc::getErrorString(__FILE__, __LINE__, "Green component is not within correct range.").c_str());
	}

	if (blue < 0 || blue > MAX_INTENSITY)
	{
		throw std::out_of_range(misc::getErrorString(__FILE__, __LINE__, "Blue component is not within correct range.").c_str());
	}
}

void Color::write(std::ostream& outputStream) const
{
	outputStream << red << "\n" << green << "\n" << blue;
}

void Color::read(std::istream& inputStream)
{
	inputStream >> red >> green >> blue;
}

std::ostream& operator<<(std::ostream& outputStream, const Color& object)
{
	object.write(outputStream);

	return outputStream;
}

std::istream& operator>>(std::istream& inputStream, Color& object)
{
	object.read(inputStream);

	return inputStream;
}

}
}