// ====================================================
//
// Copyright (c) 2002 Sean Wilson. All Rights Reserved.
//
// ====================================================

#ifndef HEADER_SEANW_GRAPHICS_COLOR
#define HEADER_SEANW_GRAPHICS_COLOR

#include "misc.h"

#include <iostream>

namespace seanw
{
namespace graphics
{

/** Represents a color. */
class Color
{
public:
	/** Constructs a color.
	 *  @param initRed           red color component, ranging inclusively from 0 to MAX_INTENSITY.
	 *  @param initGreen         green color component, ranging inclusively from 0 to MAX_INTENSITY.
	 *  @param initBlue          blue color component, ranging inclusively from 0 to MAX_INTENSITY.
	 *  @throw std::out_of_range if any components contain out of range values.
	 */
	explicit Color(int initRed = 0, int initGreen = 0, int initBlue = 0);

	/** Writes color to output stream.
	 *  @param outputStream stream to write to.
	 */
	void write(std::ostream& outputStream) const;

	/** Reads color from input stream.
	 *  @param inputStream stream to write to.
	 */	
	void read(std::istream& inputStream);

	/** Returns red color component value. */
	int getRed() const
	{
		return red;
	}

	/** Returns green color component value. */
	int getGreen() const
	{
		return green;
	}
	
	/** Returns blue color component value. */
	int getBlue() const
	{
		return blue;
	}

	/** Maximum intensity a color component can have. */ 
	static const int MAX_INTENSITY;

	/** The color black. */
	static const Color BLACK;
	/** The color white. */
	static const Color WHITE;
	/** The color red. */
	static const Color RED;
	/** The color green. */
	static const Color GREEN;
	/** The color blue. */
	static const Color BLUE;
	/** The color grey. */
	static const Color GREY;

private:
	/** Red color component. */
	int red;
	/** Green color component. */
	int green;
	/** Blue color component. */
	int blue;
};

std::ostream& operator<<(std::ostream& outputStream, const Color& object);
std::istream& operator>>(std::istream& inputStream, Color& object);

}
}

#endif