// ====================================================
//
// Copyright (c) 2002 Sean Wilson. All Rights Reserved.
//
// ====================================================

#include "graphics.h"

namespace seanw
{
namespace graphics
{

#ifdef _WIN32
Graphics::Graphics(::HDC initDc) : dc(initDc), lastPen(0), lastBrush(0)
{
	// Create and select black pen
	currentPen = ::CreatePen(PS_SOLID, 1, RGB(0, 0, 0));
	lastPen    = reinterpret_cast<::HPEN>(::SelectObject(dc, currentPen));

	// Create and select black brush
	currentBrush = ::CreateSolidBrush(RGB(0, 0, 0));
	lastBrush    = reinterpret_cast<::HBRUSH>(::SelectObject(dc, currentBrush));
}
#endif

#ifdef _WIN32
Graphics::~Graphics()
{
	::DeleteObject(::SelectObject(dc, lastPen));
	::DeleteObject(::SelectObject(dc, lastBrush));
}
#endif

#ifdef _WIN32
void Graphics::setColor(const Color& color)
{
	// Reselect last pen, delete current pen then create and select new pen 
	::DeleteObject(::SelectObject(dc, lastPen));
	currentPen = ::CreatePen(PS_SOLID, 1, RGB(color.getRed(), color.getGreen(), color.getBlue()));
	lastPen     = reinterpret_cast<::HPEN>(::SelectObject(dc, currentPen));

	// Reselect last brush, delete current brush then create and select new brush
	::DeleteObject(::SelectObject(dc, lastBrush));
	currentBrush = ::CreateSolidBrush(RGB(color.getRed(), color.getGreen(), color.getBlue()));
	lastBrush    = reinterpret_cast<::HBRUSH>(::SelectObject(dc, currentBrush));
}
#endif

#ifdef _WIN32
void Graphics::fillCircle(int x, int y, int radius)
{
	::Ellipse(dc, x - radius,
	              y - radius,
	              x + radius,
	              y + radius);
}
#endif

#ifdef _WIN32
void Graphics::drawCircle(int x, int y, int radius)
{
	::Arc(dc, x - radius,
	          y - radius,
	          x + radius,
	          y + radius,
	          0, 0, 0, 0);
}
#endif

#ifdef _WIN32
void Graphics::drawLine(int x1, int y1, int x2, int y2)
{
	::MoveToEx(dc, x1, y1, 0);
	::LineTo  (dc, x2, y2);
}
#endif

#ifdef _WIN32
void Graphics::fillRectangle(int x, int y, int width, int height)
{
	::RECT rectangle = {x, y, width, height};

	::FillRect(dc, &rectangle, currentBrush);
}
#endif

}
}