// ====================================================
//
// Copyright (c) 2002 Sean Wilson. All Rights Reserved.
//
// ====================================================

#ifndef HEADER_SEANW_MISC
#define HEADER_SEANW_MISC

#include <sstream>

namespace seanw
{
namespace misc
{

/** Makes a error message.
 *  @param filename filename error occured in.
 *  @param line     line number error occured on.
 *  @param message  cause of error
 *  @return         error message containing supplied information.
 */
std::string getErrorString(const char* filename, int line, const char* message);

/** Sets all the bits in memory that x occupies to zero.
 *  @param x variable that holds memory to be cleared.
 */
template <class T> void zeroMemory(T& x)
{
	::memset(&x, 0, sizeof(x));
}

/** Converts object to string representation defined by std::ostringstream.
 *  @param x object to convert.
 *  @return  string representation of object.
 */
template <class T> std::string toString(const T& x)
{
	std::ostringstream stringstream;

	stringstream << x;

	return stringstream.str();
}

}
}

#endif